Simpler and faster implementation of the *OPEX JSON file format* for object detection
predictions (https://github.com/WaikatoLink2020/objdet-predictions-exchange-format).

It is possible to use the orjson library (https://github.com/ijl/orjson) as backend
instead of the one from the standard library for further speed-ups.
